@@ -383,7 +383,7 @@ sub _inflate_object
 
 sub _do_strptime {
     my ($self, $string, $format) = @_;
-    my $parser = DateTime::Format::Strptime->new(pattern => $format);
+    my $parser = DateTime::Format::Strptime->new(pattern => $format, time_zone => 'UTC');
     return $parser->parse_datetime($string);
 }
 
